package com.fs.his.mapper;

import java.util.List;
import com.fs.his.domain.FsDoctorArticleCate;
import com.fs.his.vo.OptionsVO;
import org.apache.ibatis.annotations.Select;

/**
 * 医生文章分类Mapper接口
 *
 * @author fs
 * @date 2024-05-08
 */
public interface FsDoctorArticleCateMapper
{
    /**
     * 查询医生文章分类
     *
     * @param cateId 医生文章分类主键
     * @return 医生文章分类
     */
    public FsDoctorArticleCate selectFsDoctorArticleCateByCateId(Long cateId);

    /**
     * 查询医生文章分类列表
     *
     * @param fsDoctorArticleCate 医生文章分类
     * @return 医生文章分类集合
     */
    public List<FsDoctorArticleCate> selectFsDoctorArticleCateList(FsDoctorArticleCate fsDoctorArticleCate);

    /**
     * 新增医生文章分类
     *
     * @param fsDoctorArticleCate 医生文章分类
     * @return 结果
     */
    public int insertFsDoctorArticleCate(FsDoctorArticleCate fsDoctorArticleCate);

    /**
     * 修改医生文章分类
     *
     * @param fsDoctorArticleCate 医生文章分类
     * @return 结果
     */
    public int updateFsDoctorArticleCate(FsDoctorArticleCate fsDoctorArticleCate);

    /**
     * 删除医生文章分类
     *
     * @param cateId 医生文章分类主键
     * @return 结果
     */
    public int deleteFsDoctorArticleCateByCateId(Long cateId);

    /**
     * 批量删除医生文章分类
     *
     * @param cateIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteFsDoctorArticleCateByCateIds(Long[] cateIds);
    @Select("select cate_id dictValue,cate_name dictLabel FROM fs_doctor_article_cate")
    List<OptionsVO> selectFsArticleCateAllList();
}
